Learn R Programming

octopusR (version 1.0.1)

check_logical: Check a logical argument is in a suitable format

Description

Check if a given argument is of a logical. If not it will give an informative error message.

Usage

check_logical(arg_lgl)

Arguments

arg_lgl

The argument to check