By default, results will be public energy products but if authenticated organisations will also see products available to their organisation.
get_products(
is_variable = NULL,
is_green = NULL,
is_tracker = NULL,
is_prepay = NULL,
is_business = FALSE,
available_at = Sys.Date(),
authenticate = FALSE,
api_key = NULL
)a tibble
(boolean, optional) Show only variable products.
(boolean, optional) Show only green products.
(boolean, optional) Show only tracker products.
(boolean, optional) Show only pre-pay products.
(boolean, default: FALSE) Show only business products.
Show products available for new agreements on the given datetime. Defaults to current datetime, effectively showing products that are currently available.
(boolean, default: FALSE) Use an api_key to
authenticate. Only useful for organisations.
Your API key. If you are an Octopus Energy customer, you can generate an API key on the developer dashboard.